==> com.liferay.gradle.plugins.workspace-1.10.7-sources-commercial.jar: com/liferay/gradle/plugins/workspace/internal/configurators/TargetPlatformRootProjectConfigurator.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.gradle.plugins.workspace.internal.configurators;

import com.liferay.gradle.plugins.LiferayOSGiPlugin;
import com.liferay.gradle.plugins.target.platform.TargetPlatformIDEPlugin;
import com.liferay.gradle.plugins.target.platform.TargetPlatformPlugin;
import com.liferay.gradle.plugins.target.platform.extensions.TargetPlatformExtension;
import com.liferay.gradle.plugins.target.platform.extensions.TargetPlatformIDEExtension;
import com.liferay.gradle.plugins.workspace.WorkspaceExtension;
import com.liferay.gradle.plugins.workspace.configurators.RootProjectConfigurator;
import com.liferay.gradle.plugins.workspace.internal.util.GradleUtil;
import com.liferay.gradle.util.Validator;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.gradle.api.Action;
import org.gradle.api.GradleException;
import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.artifacts.Configuration;
import org.gradle.api.artifacts.DependencySet;
import org.gradle.api.plugins.ExtensionAware;
import org.gradle.api.plugins.PluginContainer;
import org.gradle.api.specs.Spec;

/**
 * @author Andrea Di Giorgi
 */
public class TargetPlatformRootProjectConfigurator implements Plugin<Project> {

	public static final Plugin<Project> INSTANCE =
		new TargetPlatformRootProjectConfigurator();

	@Override
	public void apply(final Project project) {
		WorkspaceExtension workspaceExtension = GradleUtil.getExtension(
			(ExtensionAware)project.getGradle(), WorkspaceExtension.class);

		final String targetPlatformVersion =
			workspaceExtension.getTargetPlatformVersion();

		if (Validator.isNull(targetPlatformVersion)) {
			return;
		}

		Matcher matcher = _externalVersionPattern.matcher(
			targetPlatformVersion);

		String normalizedTargetPlatformVersion = null;

		if (matcher.matches()) {
			StringBuilder sb = new StringBuilder();

			sb.append(matcher.group(1));
			sb.append('.');
			sb.append(matcher.group(2));
			sb.append('.');

			String label = matcher.group(3);

			try {
				int labelNumber = Integer.parseInt(matcher.group(4));

				if (label.startsWith("GA")) {
					sb.append(labelNumber - 1);
				}
				else if (label.startsWith("sp")) {
					sb.append(labelNumber);
				}
			}
			catch (NumberFormatException nfe) {
				throw new GradleException(
					"Invalid version property value", nfe);
			}

			normalizedTargetPlatformVersion = sb.toString();
		}
		else {
			normalizedTargetPlatformVersion = targetPlatformVersion;
		}

		GradleUtil.applyPlugin(project, TargetPlatformIDEPlugin.class);

		_configureConfigurationBundles(project);
		_configureTargetPlatform(project);
		_configureTargetPlatformIDE(project);

		_addDependenciesTargetPlatformBoms(
			project, normalizedTargetPlatformVersion);
		_addDependenciesTargetPlatformDistro(
			project, normalizedTargetPlatformVersion);
	}

	private TargetPlatformRootProjectConfigurator() {
	}

	private void _addDependenciesTargetPlatformBoms(
		Project project, String targetPlatformVersion) {

		Matcher matcher = _dxpVersionPattern.matcher(targetPlatformVersion);

		String bomArtifactId = null;
		String bomCompileOnlyArtifactId = null;

		if (matcher.matches()) {
			bomArtifactId = _ARTIFACT_ID_RELEASE_DXP_BOM;
			bomCompileOnlyArtifactId =
				_ARTIFACT_ID_RELEASE_DXP_BOM_COMPILE_ONLY;
		}
		else {
			bomArtifactId = _ARTIFACT_ID_RELEASE_PORTAL_BOM;
			bomCompileOnlyArtifactId =
				_ARTIFACT_ID_RELEASE_PORTAL_BOM_COMPILE_ONLY;
		}

		GradleUtil.addDependency(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_BOMS_CONFIGURATION_NAME,
			_GROUP_ID_LIFERAY_PORTAL, bomArtifactId, targetPlatformVersion);
		GradleUtil.addDependency(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_BOMS_CONFIGURATION_NAME,
			_GROUP_ID_LIFERAY_PORTAL, bomCompileOnlyArtifactId,
			targetPlatformVersion);
	}

	private void _addDependenciesTargetPlatformDistro(
		final Project project, final String targetPlatformVersion) {

		Configuration configuration = GradleUtil.getConfiguration(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_DISTRO_CONFIGURATION_NAME);

		configuration.defaultDependencies(
			new Action<DependencySet>() {

				@Override
				public void execute(DependencySet dependencySet) {
					Matcher matcher = _dxpVersionPattern.matcher(
						targetPlatformVersion);

					String artifactId = _ARTIFACT_ID_RELEASE_PORTAL_DISTRO;

					if (matcher.matches()) {
						artifactId = _ARTIFACT_ID_RELEASE_DXP_DISTRO;
					}

					GradleUtil.addDependency(
						project,
						TargetPlatformPlugin.
							TARGET_PLATFORM_DISTRO_CONFIGURATION_NAME,
						_GROUP_ID_LIFERAY_PORTAL, artifactId,
						targetPlatformVersion);
				}

			});
	}

	private void _configureConfigurationBundles(Project project) {
		Configuration configuration = GradleUtil.getConfiguration(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_BUNDLES_CONFIGURATION_NAME);

		Configuration providedModulesConfiguration =
			GradleUtil.getConfiguration(
				project,
				RootProjectConfigurator.PROVIDED_MODULES_CONFIGURATION_NAME);

		configuration.extendsFrom(providedModulesConfiguration);
	}

	private void _configureTargetPlatform(Project project) {
		TargetPlatformExtension targetPlatformExtension =
			GradleUtil.getExtension(project, TargetPlatformExtension.class);

		targetPlatformExtension.resolveOnlyIf(
			new Spec<Project>() {

				@Override
				public boolean isSatisfiedBy(Project project) {
					String projectName = project.getName();

					if (projectName.endsWith("-test")) {
						return false;
					}

					return true;
				}

			});

		targetPlatformExtension.resolveOnlyIf(
			new Spec<Project>() {

				@Override
				public boolean isSatisfiedBy(Project project) {
					PluginContainer pluginContainer = project.getPlugins();

					if (pluginContainer.hasPlugin(LiferayOSGiPlugin.class)) {
						return true;
					}

					return false;
				}

			});
	}

	private void _configureTargetPlatformIDE(Project project) {
		TargetPlatformIDEExtension targetPlatformIDEExtension =
			GradleUtil.getExtension(project, TargetPlatformIDEExtension.class);

		targetPlatformIDEExtension.includeGroups(
			"com.liferay", "com.liferay.portal");
	}

	private static final String _ARTIFACT_ID_RELEASE_DXP_BOM =
		"release.dxp.bom";

	private static final String _ARTIFACT_ID_RELEASE_DXP_BOM_COMPILE_ONLY =
		"release.dxp.bom.compile.only";

	private static final String _ARTIFACT_ID_RELEASE_DXP_DISTRO =
		"release.dxp.distro";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_BOM =
		"release.portal.bom";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_BOM_COMPILE_ONLY =
		"release.portal.bom.compile.only";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_DISTRO =
		"release.portal.distro";

	private static final String _GROUP_ID_LIFERAY_PORTAL = "com.liferay.portal";

	private static final Pattern _dxpVersionPattern = Pattern.compile(
		"7\\.[0-2]\\.1[0-9](\\.[0-9]+)?");

	private final Pattern _externalVersionPattern = Pattern.compile(
		"([0-9]+)\\.([0-9]+)-([A-Za-z]+)([0-9]+)");

}

==> com.liferay.gradle.plugins.workspace-3.4.21-sources-commercial.jar: com/liferay/gradle/plugins/workspace/internal/configurators/TargetPlatformRootProjectConfigurator.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.gradle.plugins.workspace.internal.configurators;

import com.liferay.gradle.plugins.LiferayOSGiPlugin;
import com.liferay.gradle.plugins.target.platform.TargetPlatformIDEPlugin;
import com.liferay.gradle.plugins.target.platform.TargetPlatformPlugin;
import com.liferay.gradle.plugins.target.platform.extensions.TargetPlatformExtension;
import com.liferay.gradle.plugins.workspace.WorkspaceExtension;
import com.liferay.gradle.plugins.workspace.internal.util.GradleUtil;
import com.liferay.gradle.plugins.workspace.internal.util.VersionUtil;
import com.liferay.gradle.util.Validator;

import org.gradle.api.Action;
import org.gradle.api.Plugin;
import org.gradle.api.Project;
import org.gradle.api.artifacts.Configuration;
import org.gradle.api.artifacts.DependencySet;
import org.gradle.api.plugins.ExtensionAware;
import org.gradle.api.plugins.PluginContainer;
import org.gradle.api.specs.Spec;

/**
 * @author Andrea Di Giorgi
 * @author Raymond Augé
 */
public class TargetPlatformRootProjectConfigurator implements Plugin<Project> {

	public static final Plugin<Project> INSTANCE =
		new TargetPlatformRootProjectConfigurator();

	@Override
	public void apply(Project project) {
		WorkspaceExtension workspaceExtension = GradleUtil.getExtension(
			(ExtensionAware)project.getGradle(), WorkspaceExtension.class);

		String targetPlatformVersion =
			workspaceExtension.getTargetPlatformVersion();

		if (Validator.isNull(targetPlatformVersion)) {
			return;
		}

		GradleUtil.applyPlugin(project, TargetPlatformIDEPlugin.class);

		_configureTargetPlatform(project);

		String normalizedTargetPlatformVersion =
			VersionUtil.normalizeTargetPlatformVersion(targetPlatformVersion);

		_addDependenciesTargetPlatformBoms(
			project, normalizedTargetPlatformVersion);
		_addDependenciesTargetPlatformDistro(
			project, normalizedTargetPlatformVersion);
	}

	private TargetPlatformRootProjectConfigurator() {
	}

	private void _addDependenciesTargetPlatformBoms(
		Project project, String targetPlatformVersion) {

		String bomArtifactId = null;
		String bomCompileOnlyArtifactId = null;
		String bomThirdPartyArtifactId = null;

		if (VersionUtil.isDXPVersion(targetPlatformVersion)) {
			bomArtifactId = _ARTIFACT_ID_RELEASE_DXP_BOM;
			bomCompileOnlyArtifactId =
				_ARTIFACT_ID_RELEASE_DXP_BOM_COMPILE_ONLY;
			bomThirdPartyArtifactId = _ARTIFACT_ID_RELEASE_DXP_BOM_THIRD_PARTY;
		}
		else {
			bomArtifactId = _ARTIFACT_ID_RELEASE_PORTAL_BOM;
			bomCompileOnlyArtifactId =
				_ARTIFACT_ID_RELEASE_PORTAL_BOM_COMPILE_ONLY;
			bomThirdPartyArtifactId =
				_ARTIFACT_ID_RELEASE_PORTAL_BOM_THIRD_PARTY;
		}

		GradleUtil.addDependency(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_BOMS_CONFIGURATION_NAME,
			_GROUP_ID_LIFERAY_PORTAL, bomThirdPartyArtifactId,
			targetPlatformVersion);

		GradleUtil.addDependency(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_BOMS_CONFIGURATION_NAME,
			_GROUP_ID_LIFERAY_PORTAL, bomArtifactId, targetPlatformVersion);

		GradleUtil.addDependency(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_BOMS_CONFIGURATION_NAME,
			_GROUP_ID_LIFERAY_PORTAL, bomCompileOnlyArtifactId,
			targetPlatformVersion);
	}

	private void _addDependenciesTargetPlatformDistro(
		final Project project, final String targetPlatformVersion) {

		Configuration configuration = GradleUtil.getConfiguration(
			project,
			TargetPlatformPlugin.TARGET_PLATFORM_DISTRO_CONFIGURATION_NAME);

		configuration.defaultDependencies(
			new Action<DependencySet>() {

				@Override
				public void execute(DependencySet dependencySet) {
					String artifactId = _ARTIFACT_ID_RELEASE_PORTAL_DISTRO;

					if (VersionUtil.isDXPVersion(targetPlatformVersion)) {
						artifactId = _ARTIFACT_ID_RELEASE_DXP_DISTRO;
					}

					GradleUtil.addDependency(
						project,
						TargetPlatformPlugin.
							TARGET_PLATFORM_DISTRO_CONFIGURATION_NAME,
						_GROUP_ID_LIFERAY_PORTAL, artifactId,
						targetPlatformVersion);
				}

			});
	}

	private void _configureTargetPlatform(Project project) {
		TargetPlatformExtension targetPlatformExtension =
			GradleUtil.getExtension(project, TargetPlatformExtension.class);

		targetPlatformExtension.resolveOnlyIf(
			new Spec<Project>() {

				@Override
				public boolean isSatisfiedBy(Project project) {
					String projectName = project.getName();

					if (projectName.endsWith("-test")) {
						return false;
					}

					return true;
				}

			});

		targetPlatformExtension.resolveOnlyIf(
			new Spec<Project>() {

				@Override
				public boolean isSatisfiedBy(Project project) {
					PluginContainer pluginContainer = project.getPlugins();

					if (pluginContainer.hasPlugin(LiferayOSGiPlugin.class)) {
						return true;
					}

					return false;
				}

			});
	}

	private static final String _ARTIFACT_ID_RELEASE_DXP_BOM =
		"release.dxp.bom";

	private static final String _ARTIFACT_ID_RELEASE_DXP_BOM_COMPILE_ONLY =
		"release.dxp.bom.compile.only";

	private static final String _ARTIFACT_ID_RELEASE_DXP_BOM_THIRD_PARTY =
		"release.dxp.bom.third.party";

	private static final String _ARTIFACT_ID_RELEASE_DXP_DISTRO =
		"release.dxp.distro";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_BOM =
		"release.portal.bom";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_BOM_COMPILE_ONLY =
		"release.portal.bom.compile.only";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_BOM_THIRD_PARTY =
		"release.portal.bom.third.party";

	private static final String _ARTIFACT_ID_RELEASE_PORTAL_DISTRO =
		"release.portal.distro";

	private static final String _GROUP_ID_LIFERAY_PORTAL = "com.liferay.portal";

}
